# Form Element

A form element is a component that is used to collect user input. It is a wrapper around the native HTML form elements.

## Key Features

- **Versatile HTML Attributes**: Enables the inclusion of custom HTML attributes for the form element container.
- **Error Handling**: Displays any errors associated with the form element, enhancing user feedback and interaction.
- **Prefix and Suffix**: Supports optional prefix and suffix for the form element, allowing for additional contextual information or styling.
- **Label and Description Management**: Offers multiple display options for labels and descriptions, including visibility settings for screen readers.
- **Required Field Indicator**: Includes a marker for required fields, improving form usability and user guidance.
- **Disabled State Support**: Allows for the form element to be marked as disabled.
- **Customizable Classes**: Incorporates `form_element_utility_classes` for additional styling options.

## Template Structure

- **Classes Configuration**: A set of predefined and customizable classes that define the appearance and behavior of the form element.
- **Error Display**: Error messages are shown in a dedicated area, improving user error recognition.
- **Label Rendering**: Labels can be positioned before or after the element, with options for visibility adjustments.
- **Description Handling**: Descriptions can be displayed before or after the element, with support for invisible display for accessibility.
- **Grouping and Accessibility**: The form element is wrapped in a div with classes for grouping and accessibility enhancements.

## Customization

- **Label and Description Settings**: Customize the position and visibility of labels and descriptions to suit different form layouts and accessibility needs.
- **Prefix/Suffix Addition**: Add contextual prefixes or suffixes to the form element for enhanced user understanding.
- **Error Styling**: Style the error messages to align with your application's design language.

## Usage

```twig
  {% include "radix:form-element" %}
```
